﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using TFCDataLayer;

namespace TFCLinkLayer.Enterprises
{
    public class Contacts
    {        

        public static EmpresaContacte getInstance()
        {
            return new EmpresaContacte () ;
        }

        public static EmpresaContacte getContactById(Guid contactId)
        {
            var context = new TFCDataModelContainer();

            var query = (from contac in context.EmpresaContactes
                         where contac.IdEmpleat == contactId
                         select contac).FirstOrDefault();
            return query;
        }

        public static IQueryable<EmpresaContacte> getEnterpriseContacts(Guid enterpriseID)
        {
            var context = new TFCDataModelContainer();
            var contact = from cont in context.EmpresaContactes
                          where cont.IdEmpresa == enterpriseID
                          select cont;
            return contact;
        }

        public static bool updateContact(EmpresaContacte contacte, out ContactsResponse resposta)
        {
            var context = new TFCDataModelContainer();
            try
            {
                var validEmail = (from em in context.EmpresaContactes
                                 where (em.Email == contacte.Email && em.IdEmpleat != contacte.IdEmpleat)
                                 select em).FirstOrDefault();
                if (validEmail != null)
                {
                    resposta = ContactsResponse.DuplicateEmail ;
                    return false;
                }
                var contact = (from cont in context.EmpresaContactes
                               where cont.IdEmpleat == contacte.IdEmpleat
                               select cont).FirstOrDefault();
                contact.Nom = contacte.Nom;
                contact.Cognom1 = contacte.Cognom1;
                contact.Cognom2 = contacte.Cognom2;
                contact.Telefon = contacte.Telefon;
                contact.Email = contacte.Email;
                contact.Actiu = contacte.Actiu;
                context.SaveChanges();
                resposta = ContactsResponse.Correct;
                return true;
            }
            catch
            {
                resposta = ContactsResponse.Error;
                return false;
            }
        }

        public static bool addContact(EmpresaContacte contacte)
        {
            try
            {
                var context = new TFCDataModelContainer();
                context.EmpresaContactes.AddObject(contacte);
                context.SaveChanges();
                return true;
            }
            catch
            {
                return false;
            }
        }

        public static bool deleteContact(Guid contactId)
        {
            var context = new TFCDataModelContainer();

            var query = (from cont in context.EmpresaContactes
                        where cont.IdEmpleat == contactId
                        select cont).FirstOrDefault();

            context.EmpresaContactes.DeleteObject(query);
            context.SaveChanges();
            return true;
        }

        public static bool validateEmail(string Email, Guid? id)
        {
            var context = new TFCDataModelContainer();
            int contador;
            if (id != null)
                contador = (from ss in context.EmpresaContactes
                        where (ss.Email == Email && ss.IdEmpleat != id)
                        select ss).Count();
            else
                contador = (from ss in context.EmpresaContactes
                            where (ss.Email == Email)
                            select ss).Count();
            if (contador > 0)
                return false;
            else
                return true;
        }

        

    }

    public enum ContactsResponse 
    {
        DuplicateEmail,
        DuplicateNif,
        Error,
        Correct
    }
}
