﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using TFCDataLayer;

namespace TFCLinkLayer.Enterprises
{
    public class Enterprise
    {

        public static Empresa getInstance()
        {
            return new Empresa();
        }

        public static IQueryable getAdminEnterprises()
        {
            var context = new TFCDataModelContainer();
            var query = from emp in context.Empreses
                        select new
                        {
                            IdEmpresa = emp.IdEmpresa,
                            NomEmpresa = emp.Nom,
                            Nif = emp.Nif,
                            provincia = emp.Provincia.Nom,
                            municipi = emp.Municipi.Nom,
                            Email = emp.Email,
                            Actiu = emp.Actiu
                        };
            return query;


        }

        public static Empresa getEnterpriseById(Guid enterpriseID)
        {
            var context = new TFCDataModelContainer();
            var enterprise = (from ent in context.Empreses
                              where ent.IdEmpresa == enterpriseID
                              select ent).FirstOrDefault() as Empresa;
            return enterprise;
        }

        public static EmpresaContacte autenthicateEnterpriseUser(string login, string password)
        {
            try
            {
                var context = new TFCDataModelContainer();
                var query = (from tr in context.EmpresaContactes
                             where tr.Email == login
                             where tr.Password == password                             
                             select tr).Single();

                return query;
            }
            catch
            {
                throw new Exception("El nom d'usuari o la contrasenya no són correctes");
            }
        }

        public static bool activateEnterprise(Guid EmployeeID)
        {
            bool alreadyActivate = false;
            try
            {
                var context = new TFCDataModelContainer();
                var query = (from emp in context.Empreses.Include("EmpresaContactes")
                             from empcont in context.EmpresaContactes
                             where emp.IdEmpresa == empcont.IdEmpresa                         
                             where empcont.IdEmpleat == EmployeeID
                             //where empcont.Activat == false
                             select new { emp, empcont }).Single();
                if (!query.empcont.Activat)
                {
                    query.emp.Activat = true;
                    query.empcont.Activat = true;
                    context.SaveChanges();
                    return true;
                }
                else
                {
                    alreadyActivate = true;
                    throw new Exception("El compte ja està activat");
                }
            }
            catch (Exception ex)
            {
                //throw new Exception("L'empresa i el treballador ja estan activats");
                if (alreadyActivate)
                    throw new Exception(ex.Message);
                else
                    throw new Exception("No es troba el compte a activar");

            }
            
        }

        public static bool addEnterpriseContact(Empresa empresa, EmpresaContacte contacte)
        {
            var context = new TFCDataModelContainer();

            var count1 = (from ent in context.Empreses
                         where (ent.Nif.Trim().ToUpper() == empresa.Nif.Trim().ToUpper() || 
                             ent.Email.Trim().ToUpper() == empresa.Email.Trim().ToUpper())
                         select ent).Count();

            var count2 = (from treb in context.EmpresaContactes
                          where treb.Email.Trim().ToUpper() == empresa.Email.Trim().ToUpper()
                          select treb).Count();

            if (count1 > 0)
                throw new Exception ("La empresa ja està donada d'alta al sistema.");
            else if (count2 > 0)
                throw new Exception ("El treballador associat a l'empresa ja es troba donat d'alta.");
            else
            {
                context.Empreses.AddObject(empresa);
                context.EmpresaContactes.AddObject(contacte);
                context.SaveChanges();
                return true;
            }

            
        }

        public static bool updateEnterprise(Empresa empresa)
        {
            var context = new TFCDataModelContainer();
            var enter = (from emp in context.Empreses
                         where emp.IdEmpresa == empresa.IdEmpresa
                         select emp).FirstOrDefault() as Empresa;
            enter.Nom = empresa.Nom;
            enter.Nif = empresa.Nif;
            enter.Adreca = empresa.Adreca;
            enter.CodiMunicipi = empresa.CodiMunicipi;
            enter.CodiProvincia = empresa.CodiProvincia;
            enter.Email = empresa.Email;
            enter.Telefon = empresa.Telefon;
            enter.Fax = empresa.Fax;
            enter.Mobil = empresa.Mobil;
            enter.Descripcio = empresa.Descripcio;


            context.SaveChanges();
            return true;


        }

    }
}
